pub struct Lockfile {
pub unity_version: String,
pub unity_path: String,
pub lang_version: String,
pub analyzers: Vec<String>,
pub refs: BTreeMap<RefCategory, Vec<DllRef>>,
pub defines: Vec<String>,
pub defines_scripting: Vec<String>,
}Fields
unity_version: Stringunity_path: Stringlang_version: Stringanalyzers: Vec<String>refs: BTreeMap<RefCategory, Vec<DllRef>>defines: Vec<String>defines_scripting: Vec<String>Implementations
Sourceimpl Lockfile
impl Lockfile
Sourcepub fn empty(
unity_version: impl Into<String>,
unity_path: impl Into<String>,
) -> Self
pub fn empty( unity_version: impl Into<String>, unity_path: impl Into<String>, ) -> Self
Build an empty lockfile shell with all RefCategory keys populated to
empty Vecs. Useful for tests and for downstream crates that want to
programmatically construct a Lockfile without spelling out every category.
pub fn total_ref_count(&self) -> usize
pub fn refs_for(&self, cat: RefCategory) -> &[DllRef]