xml_escape

Function xml_escape 

pub fn xml_escape(value: &str) -> String
XML-escape a value for an attribute or text node. Matches the five substitutions used by the Swift generator (&, ", <, >, ').